@@ -16,7 +16,7 @@ mod output;
 
 /// List of Git commands that suport the `--color` option.  Only commands shown
 /// here will have `--color` set in the spawned process.
-const COMMANDS: &[&'static str] = &["blame", "branch", "diff", "diff-index",
+const COMMANDS: &[&'static str] = &["branch", "diff", "diff-index",
     "format-patch", "grep", "log", "reflog", "rev-list", "shortlog", "show"];
 
 #[derive(Debug)]
@@ -30,7 +30,7 @@ fn main() {
 
     let git_command_args = matches.values_of("cmd").unwrap();
     let git_command: Arc<Vec<String>> = Arc::new(git_command_args.map(String::from).collect());
-    let git_color_arg: Arc<String> = Arc::new(format!("--color {}", cli::get_color_mode(&matches)));
+    let git_color_arg: Arc<String> = Arc::new(format!("--color={}", cli::get_color_mode(&matches)));
 
     let pool = rayon::ThreadPoolBuilder::new().build().unwrap();
     let (tx, rx) = channel::<GitResult>();
